diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Dwarven-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Dwarven-errata-playtest.hjson
index 31cc5d600..43c96e1a9 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Dwarven-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Dwarven-errata-playtest.hjson
@@ -3,7 +3,7 @@
71_9: {
cardInfo: {
//Either a full URL, or a subpath for the PC image server
- imagePath: errata/LOTR-EN01E009.1_card.jpg
+ imagePath: errata/LOTR-EN01E009.2_card.jpg
//If this is true, then all gameplay-related info outside this cardInfo definition
// will be ignored and the java class loaded instead.
javaClass: false
@@ -28,7 +28,7 @@
unique: false
side: Free Peoples
culture: Dwarven
- twilight: 0
+ twilight: 1
type: Possession
itemclass: Hand weapon
#target: name(Gimli)
@@ -45,7 +45,7 @@
}
]*/
- gametext: Bearer must be a Dwarf.
Each time a minion loses a skirmish to bearer, make a minion strength -1 until the regroup phase. The Shadow player may discard a minion to prevent this.
+ gametext: Bearer must be a Dwarf.
Each time a minion loses a skirmish to bearer, make a minion strength -1 until the regroup phase. The Shadow player may discard 2 cards from the bottom of their draw deck to prevent this.
lore: “‘Buckler and corslet, axe and sword / And shining spears were laid in hoard.'”
promotext: ""
alts: {
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Gandalf-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Gandalf-errata-playtest.hjson
index 1412c7044..49b35f849 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Gandalf-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Gandalf-errata-playtest.hjson
@@ -270,7 +270,7 @@
culture: Gandalf
twilight: 1
type: Event
- keyword:
+ keyword: Fellowship
/*requires: [
]
@@ -285,7 +285,7 @@
}
]
}*/
- gametext: Fellowship: Play a Wizard or [gandalf] ally from your draw deck.
+ gametext: Play a Wizard or [gandalf] ally from your draw deck.
lore: “‘A wizard is never late, Frodo Baggins, nor is he early. He arrives precisely when he means to.'”
promotext: ""
alts: {
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Gondor-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Gondor-errata-playtest.hjson
index 9f210289d..3b75bd0f3 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Gondor-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set01-Gondor-errata-playtest.hjson
@@ -201,22 +201,25 @@
culture: Gondor
twilight: 0
type: Event
- keyword:
+ keyword: Response
/*requires: [
]
effects: {
- type: event
+ type: responseEvent
+ trigger: {
+
+ }
cost: {
- },
+ }
effect: [
{
}
]
- }*/
- gametext: Response: If a skirmish event is played during a skirmish involving a [gondor] companion, cancel that event.
+ ]*/
+ gametext: If a skirmish event is played during a skirmish involving a [gondor] companion, cancel that event.
lore: “‘Believe not that in the land of Gondor the blood of Númenor is spent, nor all its pride and dignity forgotten.'”
promotext: ""
alts: {
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set02-Elven-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set02-Elven-errata-playtest.hjson
index 87d32f026..27a8c3884 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set02-Elven-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set02-Elven-errata-playtest.hjson
@@ -30,7 +30,7 @@
culture: Elven
twilight: 2
type: Event
- keyword:
+ keyword: Maneuver
/*requires: [
]
@@ -45,7 +45,7 @@
}
]
}*/
- gametext: Maneuver: Exert an Elf ally to discard a condition. If you can spot an Orc, you may exert another Elf ally to discard another condition.
+ gametext: Exert an Elf ally to discard a condition. If you can spot an Orc, you may exert another Elf ally to discard another condition.
lore: “‘Yet so little faith and trust do we find now in the world beyond Lothlórien... that we dare not by our own trust endanger our land.'”
promotext: ""
alts: {
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set03-Elven-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set03-Elven-errata-playtest.hjson
index bcae0df5b..986b499a7 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set03-Elven-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set03-Elven-errata-playtest.hjson
@@ -28,7 +28,7 @@
unique: true
side: Free Peoples
culture: Elven
- twilight: 2
+ twilight: 1
type: Artifact
itemclass: Ring
#target: name(Gimli)
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set04-Sites-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set04-Sites-errata-playtest.hjson
index c0db0ed9d..4a2014399 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set04-Sites-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set04-Sites-errata-playtest.hjson
@@ -41,7 +41,7 @@
}
]*/
- gametext: Skirmish events may not be played and skirmish special abilities may not be used.
+ gametext: At the start of each skirmish, you may exert your character in that skirmish to prevent special abilities being used.
lore: ""
promotext: ""
alts: {
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set06-Elven-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set06-Elven-errata-playtest.hjson
index 41495093b..a1c868d95 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set06-Elven-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set06-Elven-errata-playtest.hjson
@@ -29,20 +29,23 @@
side: Free Peoples
culture: Elven
twilight: 1
- type: Condition
- #keyword: support area
+ type: Event
+ keyword: Skirmish
/*requires: [
]
- effects: [
- {
+ effects: {
+ type: event
+ cost: {
- }
- {
-
- }
- ]*/
- gametext: Skirmish: Reveal the top card of your draw deck to make a minion skirmishing an Elf strength –X, where X is the twilight cost of the revealed card. If that minion is now 4 strength or less, discard the revealed card.
+ },
+ effect: [
+ {
+
+ }
+ ]
+ }*/
+ gametext: Reveal the top card of your draw deck to make a minion skirmishing an Elf strength –X, where X is the twilight cost of the revealed card. If that minion is now 4 strength or less, discard the revealed card.
lore: “‘Give them a volley.'”
promotext: ""
alts: {
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set101-Gandalf-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set101-Gandalf-errata-playtest.hjson
index 51a1e28e4..ef63a991f 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set101-Gandalf-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set101-Gandalf-errata-playtest.hjson
@@ -33,7 +33,7 @@
type: Companion
race: Wizard
#keyword: damage+1
- strength: 6
+ strength: 7
vitality: 4
signet: Gandalf
resistance: 6
diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set11-Sites-errata-playtest.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set11-Sites-errata-playtest.hjson
index a7705126c..3f09eb801 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set11-Sites-errata-playtest.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/yuletide/set11-Sites-errata-playtest.hjson
@@ -3,7 +3,7 @@
81_232: {
cardInfo: {
//Either a full URL, or a subpath for the PC image server
- imagePath: errata/LOTR-EN11E232.1_card.jpg
+ imagePath: errata/LOTR-EN11E232.2_card.jpg
//If this is true, then all gameplay-related info outside this cardInfo definition
// will be ignored and the java class loaded instead.
javaClass: false
@@ -41,7 +41,7 @@
}
]*/
- gametext: Skirmish special abilities cannot be used.
+ gametext: At the start of each skirmish, you may exert your character in that skirmish to prevent special abilities being used.
lore: ""
promotext: ""
alts: {
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_009_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_009_ErrataTests.java
index 2f41dac23..89a1c0c28 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_009_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_009_ErrataTests.java
@@ -39,11 +39,11 @@ public class Card_1_009_ErrataTests
* Unique: False
* Side: FREE_PEOPLE
* Culture: Dwarven
- * Twilight Cost: 0
+ * Twilight Cost: 1
* Type: possession
* Subtype: Hand Weapon
* Strength: 2
- * Game Text: Bearer must be a Dwarf.
Each time a minion loses a skirmish to bearer, make a minion strength -1 until the regroup phase. The Shadow player may discard a minion to prevent this.
+ * Game Text: Bearer must be a Dwarf.
Each time a minion loses a skirmish to bearer, make a minion strength -1 until the regroup phase. The Shadow player may discard 2 cards from the bottom of their draw deck to prevent this.
*/
//Pre-game setup
@@ -58,7 +58,7 @@ public class Card_1_009_ErrataTests
//assertEquals(Race.HAND WEAPON, card.getBlueprint().getRace());
assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.HAND_WEAPON));
assertTrue(scn.HasKeyword(card, Keyword.SUPPORT_AREA));
- assertEquals(0, card.getBlueprint().getTwilightCost());
+ assertEquals(1, card.getBlueprint().getTwilightCost());
assertEquals(2, card.getBlueprint().getStrength());
//assertEquals(, card.getBlueprint().getVitality());
//assertEquals(, card.getBlueprint().getResistance());
@@ -77,6 +77,6 @@ public class Card_1_009_ErrataTests
scn.StartGame();
scn.FreepsPlayCard(card);
- assertEquals(0, scn.GetTwilight());
+ assertEquals(1, scn.GetTwilight());
}
}
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_087_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_087_ErrataTests.java
index bfb54f730..9e97bad5e 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_087_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_087_ErrataTests.java
@@ -41,8 +41,8 @@ public class Card_1_087_ErrataTests
* Culture: Gandalf
* Twilight Cost: 1
* Type: event
- * Subtype:
- * Game Text: Fellowship: Play a Wizard or [gandalf] ally from your draw deck.
+ * Subtype: Fellowship
+ * Game Text: Play a Wizard or [gandalf] ally from your draw deck.
*/
//Pre-game setup
@@ -54,8 +54,8 @@ public class Card_1_087_ErrataTests
assertEquals(Side.FREE_PEOPLE, card.getBlueprint().getSide());
assertEquals(Culture.GANDALF, card.getBlueprint().getCulture());
assertEquals(CardType.EVENT, card.getBlueprint().getCardType());
- //assertEquals(Race., card.getBlueprint().getRace());
- //assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.));
+ //assertEquals(Race.FELLOWSHIP, card.getBlueprint().getRace());
+ //assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.FELLOWSHIP));
assertTrue(scn.HasKeyword(card, Keyword.SUPPORT_AREA));
assertEquals(1, card.getBlueprint().getTwilightCost());
//assertEquals(, card.getBlueprint().getStrength());
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_115_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_115_ErrataTests.java
index 73299acb1..2c1c21d11 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_115_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_1_115_ErrataTests.java
@@ -41,8 +41,8 @@ public class Card_1_115_ErrataTests
* Culture: Gondor
* Twilight Cost: 0
* Type: event
- * Subtype:
- * Game Text: Response: If a skirmish event is played during a skirmish involving a [gondor] companion, cancel that event.
+ * Subtype: Response
+ * Game Text: If a skirmish event is played during a skirmish involving a [gondor] companion, cancel that event.
*/
//Pre-game setup
@@ -54,8 +54,8 @@ public class Card_1_115_ErrataTests
assertEquals(Side.FREE_PEOPLE, card.getBlueprint().getSide());
assertEquals(Culture.GONDOR, card.getBlueprint().getCulture());
assertEquals(CardType.EVENT, card.getBlueprint().getCardType());
- //assertEquals(Race., card.getBlueprint().getRace());
- //assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.));
+ //assertEquals(Race.RESPONSE, card.getBlueprint().getRace());
+ //assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.RESPONSE));
assertTrue(scn.HasKeyword(card, Keyword.SUPPORT_AREA));
assertEquals(0, card.getBlueprint().getTwilightCost());
//assertEquals(, card.getBlueprint().getStrength());
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_2_020_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_2_020_ErrataTests.java
index 35605af4c..2e9dc8c33 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_2_020_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_2_020_ErrataTests.java
@@ -41,8 +41,8 @@ public class Card_2_020_ErrataTests
* Culture: Elven
* Twilight Cost: 2
* Type: event
- * Subtype:
- * Game Text: Maneuver: Exert an Elf ally to discard a condition. If you can spot an Orc, you may exert another Elf ally to discard another condition.
+ * Subtype: Maneuver
+ * Game Text: Exert an Elf ally to discard a condition. If you can spot an Orc, you may exert another Elf ally to discard another condition.
*/
//Pre-game setup
@@ -54,8 +54,8 @@ public class Card_2_020_ErrataTests
assertEquals(Side.FREE_PEOPLE, card.getBlueprint().getSide());
assertEquals(Culture.ELVEN, card.getBlueprint().getCulture());
assertEquals(CardType.EVENT, card.getBlueprint().getCardType());
- //assertEquals(Race., card.getBlueprint().getRace());
- //assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.));
+ //assertEquals(Race.MANEUVER, card.getBlueprint().getRace());
+ //assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.MANEUVER));
assertTrue(scn.HasKeyword(card, Keyword.SUPPORT_AREA));
assertEquals(2, card.getBlueprint().getTwilightCost());
//assertEquals(, card.getBlueprint().getStrength());
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_3_027_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_3_027_ErrataTests.java
index c469b89d0..65fcad33d 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_3_027_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_3_027_ErrataTests.java
@@ -39,7 +39,7 @@ public class Card_3_027_ErrataTests
* Unique: True
* Side: FREE_PEOPLE
* Culture: Elven
- * Twilight Cost: 2
+ * Twilight Cost: 1
* Type: artifact
* Subtype: Ring
* Vitality: 1
@@ -59,7 +59,7 @@ public class Card_3_027_ErrataTests
//assertEquals(Race.RING, card.getBlueprint().getRace());
assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.RING));
assertTrue(scn.HasKeyword(card, Keyword.SUPPORT_AREA));
- assertEquals(2, card.getBlueprint().getTwilightCost());
+ assertEquals(1, card.getBlueprint().getTwilightCost());
//assertEquals(, card.getBlueprint().getStrength());
assertEquals(1, card.getBlueprint().getVitality());
//assertEquals(, card.getBlueprint().getResistance());
@@ -78,6 +78,6 @@ public class Card_3_027_ErrataTests
scn.StartGame();
scn.FreepsPlayCard(card);
- assertEquals(2, scn.GetTwilight());
+ assertEquals(1, scn.GetTwilight());
}
}
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_4_355_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_4_355_ErrataTests.java
index 7c6360c14..4a0f6398f 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_4_355_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_4_355_ErrataTests.java
@@ -43,7 +43,7 @@ public class Card_4_355_ErrataTests
* Type: site
* Subtype: Standard
* Site Number: 7T
- * Game Text: Skirmish events may not be played and skirmish special abilities may not be used.
+ * Game Text: At the start of each skirmish, you may exert your character in that skirmish to prevent special abilities being used.
*/
//Pre-game setup
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_V1_014_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_V1_014_ErrataTests.java
index 755236009..393d56fdf 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_V1_014_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_V1_014_ErrataTests.java
@@ -42,7 +42,7 @@ public class Card_V1_014_ErrataTests
* Twilight Cost: 4
* Type: companion
* Subtype: Wizard
- * Strength: 6
+ * Strength: 7
* Vitality: 4
* Signet: Gandalf
* Game Text: At the start of your fellowship phase, you may spot 3 [elven] allies and exert Gandalf to take a [Gandalf] or [elven] event from your discard pile into your hand.
@@ -62,7 +62,7 @@ public class Card_V1_014_ErrataTests
//assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.WIZARD));
assertTrue(scn.HasKeyword(card, Keyword.SUPPORT_AREA));
assertEquals(4, card.getBlueprint().getTwilightCost());
- assertEquals(6, card.getBlueprint().getStrength());
+ assertEquals(7, card.getBlueprint().getStrength());
assertEquals(4, card.getBlueprint().getVitality());
//assertEquals(, card.getBlueprint().getResistance());
assertEquals(Signet.GANDALF, card.getBlueprint().getSignet());
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_6_016_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_6_016_ErrataTests.java
index 8b1cf9d3d..ba496b914 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_6_016_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/_yuletide/Card_6_016_ErrataTests.java
@@ -40,9 +40,9 @@ public class Card_6_016_ErrataTests
* Side: FREE_PEOPLE
* Culture: Elven
* Twilight Cost: 1
* Type: condition
* Subtype:
* Game Text: Skirmish: Reveal the top card of your draw deck to make a minion skirmishing an Elf strength –X, where X is the twilight cost of the revealed card. If that minion is now 4 strength or less, discard the revealed card.
*/
//Pre-game setup
@@ -53,9 +53,9 @@ public class Card_6_016_ErrataTests
assertFalse(card.getBlueprint().isUnique());
assertEquals(Side.FREE_PEOPLE, card.getBlueprint().getSide());
assertEquals(Culture.ELVEN, card.getBlueprint().getCulture());
- assertEquals(CardType.CONDITION, card.getBlueprint().getCardType());
- //assertEquals(Race., card.getBlueprint().getRace());
- //assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.));
+ assertEquals(CardType.EVENT, card.getBlueprint().getCardType());
+ //assertEquals(Race.SKIRMISH, card.getBlueprint().getRace());
+ //assertTrue(card.getBlueprint().getPossessionClasses().contains(PossessionClass.SKIRMISH));
assertTrue(scn.HasKeyword(card, Keyword.SUPPORT_AREA));
assertEquals(1, card.getBlueprint().getTwilightCost());
//assertEquals(, card.getBlueprint().getStrength());
@@ -40,9 +40,9 @@ public class Card_6_016_ErrataTests
* Culture: Elven
* Twilight Cost: 1
- * Type: condition
- * Subtype:
- * Game Text: Skirmish: Reveal the top card of your draw deck to make a minion skirmishing an Elf strength –X, where X is the twilight cost of the revealed card. If that minion is now 4 strength or less, discard the revealed card.
+ * Type: event
+ * Subtype: Skirmish
+ * Game Text: Reveal the top card of your draw deck to make a minion skirmishing an Elf strength –X, where X is the twilight cost of the revealed card. If that minion is now 4 strength or less, discard the revealed card.
*/
//Pre-game setup